@@ -12,7 +12,7 @@ from inspect import getmembers
 from utility import app_path
 
 
-def reg_ui_method(name=None,intro=None):
+def reg_ui_method(name=None, intro=None):
     """
     reg ui_method
     Demo
@@ -22,7 +22,8 @@ def reg_ui_method(name=None,intro=None):
 
     """
     def actual(handler):
-        if not hasattr(handler,'__reg_ui__'):
+        ''' set attr for handler'''
+        if not hasattr(handler, '__reg_ui__'):
             handler.__reg_ui__ = True
             handler.__uiname__ = name
             handler.__intro__ = intro
@@ -34,15 +35,17 @@ def reg_ui_method(name=None,intro=None):
 
 def url(pattern, order=0):
     """
-        set router for RequestHandler 
-        Demo:
-        @url('/blog/info/(.*)')
-        class ActionHandler(tornado.web.RequestHandler):
-            def get(self,blogid):
-                pass
+    set router for RequestHandler 
+
+    Demo:
+    @url('/blog/info/(.*)')
+    class ActionHandler(tornado.web.RequestHandler):
+        def get(self,blogid):
+            pass
     """
     def actual(handler):
-        assert(issubclass(handler,tornado.web.RequestHandler))
+        ''' set attr for handler'''
+        assert(issubclass(handler, tornado.web.RequestHandler))
         if not hasattr(handler, "__urls__") or not handler.__urls__:
             handler.__urls__ = []
         handler.__urls__.append((pattern, order))
@@ -52,6 +55,7 @@ def url(pattern, order=0):
 
 
 def load_handlers(handler_dir='action'):
+    ''' load all handler in dirs '''
     dirs = handler_dir
     if isinstance(handler_dir, str):
         dirs = (handler_dir,)
@@ -87,10 +91,11 @@ def _load_handlers(handler_dir='action'):
     return _sorted_hanlders(ret.values())
 
 def _sorted_hanlders(handlers):
+    ''' sort handlers '''
     handlers = [(pattern, order, h) for h in handlers for pattern,
                 order in h.__urls__]
     handlers.sort(cmp=cmp, key=lambda x: x[1])
     return [(pattern, handler) for pattern, _, handler in handlers]
 
 
-__all__ = ["reg_ui_method","url", "load_handlers"]
+__all__ = ["reg_ui_method", "url", "load_handlers"]
